@@ -16,27 +16,34 @@ class Mensaje(BaseModel):
         extra = Extra.allow
 
     @classmethod
-    def parse_xml(cls, mensaje):
-        mensaje = etree.fromstring(mensaje)  # noqa: S320
+    def parse_xml(cls, mensaje):  # noqa: WPS210
+        decoded = mensaje.decode('latin1')
+        encoded = decoded.encode('utf-8')
+        mensaje = etree.fromstring(encoded)  # noqa: S320
         body = mensaje.find(
             '{http://schemas.xmlsoap.org/soap/envelope/}Body',
         )
         ordenpago = body.find('{http://www.praxis.com.mx/}ordenpago')
         respuesta = body.find('{http://www.praxis.com.mx/}respuesta')
-        ensesion = body.find('{http://www.praxis.com.mx/}ensesion')
 
         if ordenpago is not None:
-            element = etree.fromstring(ordenpago.text)  # noqa: S320
+            element = etree.fromstring(  # noqa: S320
+                bytes(ordenpago.text.strip(), encoding='cp850'),
+            )
             categoria = element.attrib['categoria']
+
+            if categoria == CategoriaOrdenPago.ensesion:
+                return cls(
+                    categoria=categoria, ensesion=element,
+                )
+
             return cls(categoria=categoria, ordenpago=element)
 
         if respuesta is not None:
             element = etree.fromstring(  # noqa: S320
-                bytes(respuesta.text, encoding='cp850'),
+                bytes(respuesta.text.strip(), encoding='cp850'),
             )
             categoria = element.attrib['categoria']
             return cls(categoria=categoria, respuesta=element)
 
-        return cls(
-            ensesion=ensesion,
-        )
+        raise NotImplementedError
